==> sensorpro-ble_0.7.0.orig.tar.gz: sensorpro-ble-0.7.0/CHANGELOG.md <==
# CHANGELOG


## v0.7.0 (2025-04-30)

### Chores

- **deps**: Bump bluetooth-data-tools from 1.28.0 to 1.28.1
  ([#33](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/33),
  [`a526892`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/a52689217d9288f5d01c89e2a4f1080d902c723f))

- **deps**: Bump habluetooth from 3.42.0 to 3.44.0
  ([#35](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/35),
  [`a74525e`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/a74525ee06be30bce1218ae7855104d1e04146e2))

- **deps**: Bump myst-parser from 0.18.1 to 1.0.0
  ([#26](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/26),
  [`6fd9b67`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/6fd9b67e4a41f62b40ef5369f1532dcfd400eccc))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

- **deps**: Bump sphinx from 5.3.0 to 6.2.1
  ([#34](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/34),
  [`682d292`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/682d292a87985a019a9bc98a4fb46ae68e3ce7db))

- **deps**: Bump sphinx-rtd-theme from 1.1.1 to 2.0.0
  ([#29](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/29),
  [`e9347e2`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/e9347e2a895f313291544129914cdc9c6bd88e56))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

- **deps-dev**: Bump pytest from 7.2.1 to 8.3.5
  ([#32](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/32),
  [`7849c2c`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/7849c2cb24d6678c8e3cfc06d0cc07faf7c8382d))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

- **deps-dev**: Bump pytest-cov from 3.0.0 to 6.1.1
  ([#31](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/31),
  [`8982da1`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/8982da16d2786a7b6d7e49218c247afa2d063701))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

### Features

- Use changed_manufacturer_data from newer bluetooth-sensor-state-data
  ([#36](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/36),
  [`2f47c2d`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/2f47c2d7e2ad158bc317680fec16607c237239ec))


## v0.6.0 (2025-04-28)

### Chores

- Create dependabot.yml
  ([`cd0b533`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/cd0b53337ded0563f1f5e9300bca72e0d2bde735))

- **ci**: Bump the github-actions group with 8 updates
  ([#25](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/25),
  [`8753e5c`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/8753e5c8055045d66625ca3342237d4127138256))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

Co-authored-by: J. Nick Koston <nick@koston.org>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#10](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/10),
  [`90161d6`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/90161d69e1326036760c73e81ca28cbe25a01c08))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#11](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/11),
  [`20dad54`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/20dad54867f910ea97147df62fadb42ec45fe9b1))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#12](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/12),
  [`1dabf33`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/1dabf33c87fe4321c4f4e1708bdea489dc00fa59))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#13](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/13),
  [`db150a2`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/db150a2979b6dca1728e148bbc4d5ea038cbe182))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#14](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/14),
  [`4e127c9`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/4e127c920bc7cc6876291ff662a7fcac474b5c89))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#15](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/15),
  [`4c14dc8`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/4c14dc8e928d88b8d6eebaed09068dacfa008353))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#16](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/16),
  [`de4b58d`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/de4b58d7a69158967f9926ce2903bc4a4902f8fd))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#18](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/18),
  [`3d0709d`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/3d0709d2d7b79ed3ed5b06bbcff1ace234a069c0))

- **pre-commit.ci**: Pre-commit autoupdate
  ([#19](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/19),
  [`8d8d42c`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/8d8d42c5f07f41973f14ba4fc8a34c9421386307))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#20](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/20),
  [`f39cadf`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/f39cadff1b01e4af4c3a76766219dc16a94718b5))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#21](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/21),
  [`fab72b6`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/fab72b6dce90652a9f0d9a332d4bd6975203360e))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#22](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/22),
  [`2fe12fb`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/2fe12fb3ba93b6dfd6bb4ac06afe44c0b717748c))

updates: - [github.com/commitizen-tools/commitizen: v4.2.1 →
  v4.4.1](https://github.com/commitizen-tools/commitizen/compare/v4.2.1...v4.4.1) -
  [github.com/PyCQA/isort: 6.0.0 → 6.0.1](https://github.com/PyCQA/isort/compare/6.0.0...6.0.1) -
  [github.com/PyCQA/flake8: 7.1.2 → 7.2.0](https://github.com/PyCQA/flake8/compare/7.1.2...7.2.0)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#23](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/23),
  [`02f48f8`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/02f48f86249526eabf2a866e6908f9c1374147e8))

updates: - [github.com/commitizen-tools/commitizen: v4.4.1 →
  v4.5.0](https://github.com/commitizen-tools/commitizen/compare/v4.4.1...v4.5.0)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#24](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/24),
  [`82831ab`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/82831ab3e6f512044f45862871bf2859f2fb1792))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

### Features

- Add support for raw data parsing
  ([#30](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/30),
  [`bdcf2a0`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/bdcf2a0bc13dc4deae2d4ed6e593911680aa238d))


## v0.5.3 (2023-02-07)

### Bug Fixes

- Account for switching adapter when finding changed_manufacturer_data
  ([#9](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/9),
  [`698d3c2`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/698d3c202b40ec1b3a654dc8a9ff536ff06243b2))


## v0.5.2 (2023-02-06)

### Bug Fixes

- Update isort to fix CI ([#8](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/8),
  [`1f3f186`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/1f3f18619b18f14095bd3e500d9489e7d45dd7ab))


## v0.5.1 (2022-12-17)

### Bug Fixes

- Negative temperature ([#7](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/7),
  [`8541370`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/854137058cff08a7def3f387d952b7d926919f21))


## v0.5.0 (2022-08-30)

### Features

- Add support for the t201/t301 ([#5](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/5),
  [`8235d01`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/8235d01f291e34e2cbbdce9e6dd7a888297ac84e))


## v0.4.0 (2022-08-30)

### Chores

- Initial commit
  ([`36b418a`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/36b418a94a6f261263b7173945ad47885a9f01de))

### Features

- First publish ([#2](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/2),
  [`9204233`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/92042336ef15c6653b5214c6de30e2635db34cec))

- First release ([#3](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/3),
  [`fe2afe4`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/fe2afe465232c8cad6d3822746bab0766c2feb99))

- Fix ci ([#4](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/4),
  [`caec685`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/caec685ea5c92295e20cc23f917ead5d23f7bfb8))

- Init repo ([#1](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/1),
  [`26b8d6b`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/26b8d6b8faa0fe0ff08da49e2ebf7ca653dbd8bb))

==> sensorpro-ble_1.0.0.orig.tar.gz: sensorpro-ble-1.0.0/CHANGELOG.md <==
# CHANGELOG


## v0.7.1 (2025-05-21)

### Bug Fixes

- Update poetry to v2 ([#44](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/44),
  [`88d3426`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/88d34261bbddb1c81ae52901e261eaa71489042d))

### Chores

- **deps**: Bump bluetooth-sensor-state-data from 1.8.0 to 1.9.0
  ([#43](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/43),
  [`171ecd7`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/171ecd75486d509ef2a6046474291e3fbbd47936))

- **deps**: Bump habluetooth from 3.45.0 to 3.48.2
  ([#39](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/39),
  [`96deb45`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/96deb45bb44bc2d398f80e256875bea906ef562b))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

- **deps**: Bump myst-parser from 1.0.0 to 3.0.1
  ([#38](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/38),
  [`fcc3640`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/fcc3640bb59fd0e3f687fa9879b7b8a6ef8317f6))

- **deps**: Bump sphinx from 6.2.1 to 7.4.7
  ([#42](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/42),
  [`d3492b6`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/d3492b62844404aff6bef41f812daec970e79477))

- **deps**: Bump sphinx-rtd-theme from 2.0.0 to 3.0.2
  ([#40](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/40),
  [`bdfc368`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/bdfc368e30a660e80b852560e61dc7b1fe31bab5))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#37](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/37),
  [`7a909e2`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/7a909e261bee5f15768fe0af97c1f0ceb2378b70))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>


## v0.7.0 (2025-04-30)

### Chores

- **deps**: Bump bluetooth-data-tools from 1.28.0 to 1.28.1
  ([#33](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/33),
  [`a526892`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/a52689217d9288f5d01c89e2a4f1080d902c723f))

- **deps**: Bump habluetooth from 3.42.0 to 3.44.0
  ([#35](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/35),
  [`a74525e`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/a74525ee06be30bce1218ae7855104d1e04146e2))

- **deps**: Bump myst-parser from 0.18.1 to 1.0.0
  ([#26](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/26),
  [`6fd9b67`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/6fd9b67e4a41f62b40ef5369f1532dcfd400eccc))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

- **deps**: Bump sphinx from 5.3.0 to 6.2.1
  ([#34](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/34),
  [`682d292`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/682d292a87985a019a9bc98a4fb46ae68e3ce7db))

- **deps**: Bump sphinx-rtd-theme from 1.1.1 to 2.0.0
  ([#29](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/29),
  [`e9347e2`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/e9347e2a895f313291544129914cdc9c6bd88e56))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

- **deps-dev**: Bump pytest from 7.2.1 to 8.3.5
  ([#32](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/32),
  [`7849c2c`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/7849c2cb24d6678c8e3cfc06d0cc07faf7c8382d))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

- **deps-dev**: Bump pytest-cov from 3.0.0 to 6.1.1
  ([#31](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/31),
  [`8982da1`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/8982da16d2786a7b6d7e49218c247afa2d063701))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

### Features

- Use changed_manufacturer_data from newer bluetooth-sensor-state-data
  ([#36](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/36),
  [`2f47c2d`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/2f47c2d7e2ad158bc317680fec16607c237239ec))


## v0.6.0 (2025-04-28)

### Chores

- Create dependabot.yml
  ([`cd0b533`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/cd0b53337ded0563f1f5e9300bca72e0d2bde735))

- **ci**: Bump the github-actions group with 8 updates
  ([#25](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/25),
  [`8753e5c`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/8753e5c8055045d66625ca3342237d4127138256))

Co-authored-by: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>

Co-authored-by: J. Nick Koston <nick@koston.org>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#10](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/10),
  [`90161d6`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/90161d69e1326036760c73e81ca28cbe25a01c08))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#11](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/11),
  [`20dad54`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/20dad54867f910ea97147df62fadb42ec45fe9b1))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#12](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/12),
  [`1dabf33`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/1dabf33c87fe4321c4f4e1708bdea489dc00fa59))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#13](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/13),
  [`db150a2`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/db150a2979b6dca1728e148bbc4d5ea038cbe182))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#14](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/14),
  [`4e127c9`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/4e127c920bc7cc6876291ff662a7fcac474b5c89))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#15](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/15),
  [`4c14dc8`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/4c14dc8e928d88b8d6eebaed09068dacfa008353))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#16](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/16),
  [`de4b58d`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/de4b58d7a69158967f9926ce2903bc4a4902f8fd))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#18](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/18),
  [`3d0709d`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/3d0709d2d7b79ed3ed5b06bbcff1ace234a069c0))

- **pre-commit.ci**: Pre-commit autoupdate
  ([#19](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/19),
  [`8d8d42c`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/8d8d42c5f07f41973f14ba4fc8a34c9421386307))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#20](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/20),
  [`f39cadf`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/f39cadff1b01e4af4c3a76766219dc16a94718b5))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#21](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/21),
  [`fab72b6`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/fab72b6dce90652a9f0d9a332d4bd6975203360e))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#22](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/22),
  [`2fe12fb`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/2fe12fb3ba93b6dfd6bb4ac06afe44c0b717748c))

updates: - [github.com/commitizen-tools/commitizen: v4.2.1 →
  v4.4.1](https://github.com/commitizen-tools/commitizen/compare/v4.2.1...v4.4.1) -
  [github.com/PyCQA/isort: 6.0.0 → 6.0.1](https://github.com/PyCQA/isort/compare/6.0.0...6.0.1) -
  [github.com/PyCQA/flake8: 7.1.2 → 7.2.0](https://github.com/PyCQA/flake8/compare/7.1.2...7.2.0)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#23](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/23),
  [`02f48f8`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/02f48f86249526eabf2a866e6908f9c1374147e8))

updates: - [github.com/commitizen-tools/commitizen: v4.4.1 →
  v4.5.0](https://github.com/commitizen-tools/commitizen/compare/v4.4.1...v4.5.0)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

- **pre-commit.ci**: Pre-commit autoupdate
  ([#24](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/24),
  [`82831ab`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/82831ab3e6f512044f45862871bf2859f2fb1792))

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

### Features

- Add support for raw data parsing
  ([#30](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/30),
  [`bdcf2a0`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/bdcf2a0bc13dc4deae2d4ed6e593911680aa238d))


## v0.5.3 (2023-02-07)

### Bug Fixes

- Account for switching adapter when finding changed_manufacturer_data
  ([#9](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/9),
  [`698d3c2`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/698d3c202b40ec1b3a654dc8a9ff536ff06243b2))


## v0.5.2 (2023-02-06)

### Bug Fixes

- Update isort to fix CI ([#8](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/8),
  [`1f3f186`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/1f3f18619b18f14095bd3e500d9489e7d45dd7ab))


## v0.5.1 (2022-12-17)

### Bug Fixes

- Negative temperature ([#7](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/7),
  [`8541370`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/854137058cff08a7def3f387d952b7d926919f21))


## v0.5.0 (2022-08-30)

### Features

- Add support for the t201/t301 ([#5](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/5),
  [`8235d01`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/8235d01f291e34e2cbbdce9e6dd7a888297ac84e))


## v0.4.0 (2022-08-30)

### Chores

- Initial commit
  ([`36b418a`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/36b418a94a6f261263b7173945ad47885a9f01de))

### Features

- First publish ([#2](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/2),
  [`9204233`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/92042336ef15c6653b5214c6de30e2635db34cec))

- First release ([#3](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/3),
  [`fe2afe4`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/fe2afe465232c8cad6d3822746bab0766c2feb99))

- Fix ci ([#4](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/4),
  [`caec685`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/caec685ea5c92295e20cc23f917ead5d23f7bfb8))

- Init repo ([#1](https://github.com/Bluetooth-Devices/sensorpro-ble/pull/1),
  [`26b8d6b`](https://github.com/Bluetooth-Devices/sensorpro-ble/commit/26b8d6b8faa0fe0ff08da49e2ebf7ca653dbd8bb))
